# cs207-FinalProject

[![Build Status](https://travis-ci.org/cs207group4/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/cs207group4/cs207-FinalProject)
[![Coverage Status](https://coveralls.io/repos/github/cs207group4/cs207-FinalProject/badge.svg?branch=master&maxAge=0)](https://coveralls.io/github/cs207group4/cs207-FinalProject?branch=master&maxAge=0)

pychemkin is a Python 3 library that computes the reaction rates of species participating in a system of elementary gas-phase reactions.

To install, you can simply enter   `pip install pychemkin` into the terminal.
Further documentation is in 'docs/pychemkin.pdf.' Example outputs presented in the manual can be found in the examples/ directory. A demo IPython notebook is available in the demo_notebook/ directory. 

Authors: CS207 Group 4

License: GPL v. 3
